@@ -4,7 +4,7 @@ files  <- dir(system.file(package="apex"), patter="patr", full=TRUE)
 x      <- read.multiFASTA(files)
 mulphy <- multidna2multiphyDat(x)
 gensnp <- multidna2genind(x)
-genphy <- multiphyDat2genind(x)
+genphy <- multiphyDat2genind(mulphy)
 gengen <- multidna2genind(x, mlst = TRUE, gapIsNA = TRUE)
 muldna <- multiphyDat2multidna(mulphy)
 
@@ -24,7 +24,7 @@ test_that("genind conversion works as expected", {
 
 test_that("multiphyDat conversion works as expected", {
 	expect_that(mulphy, is_a("multiphyDat"))
-	expect_that(sample(mulphy@dna, 1)[[1]], is_a("phyDat"))
+	expect_that(sample(mulphy@seq, 1)[[1]], is_a("phyDat"))
 	expect_that(muldna, is_a("multidna"))
 	expect_that(sample(muldna@dna, 1)[[1]], is_a("DNAbin"))
-})
\ No newline at end of file
+})
